@@ -81,7 +81,9 @@ class Compare(AppEndpoint, BenchmarkMixin, RunMixin, TimeSeriesPlotMixin):
         }
         plot = json.dumps(
             bokeh.embed.json_item(
-                simple_bar_plot([baseline_copy, contender_copy], height=200),
+                simple_bar_plot(
+                    [baseline_copy, contender_copy], height=200, vbar_width=0.3
+                ),
                 "plot",
             ),
         )
@@ -92,9 +94,12 @@ class Compare(AppEndpoint, BenchmarkMixin, RunMixin, TimeSeriesPlotMixin):
             return self.redirect("app.login")
 
         threshold = f.request.args.get("threshold")
+        threshold_z = f.request.args.get("threshold_z")
         params = {"compare_ids": compare_ids}
         if threshold is not None:
             params["threshold"] = threshold
+        if threshold_z is not None:
+            params["threshold_z"] = threshold_z
 
         try:
             baseline_id, contender_id = compare_ids.split("...", 1)
