@@ -17,7 +17,7 @@ class Run(Base, EntityMixin):
     machine_id = NotNull(s.String(50), s.ForeignKey("machine.id"))
     machine = relationship("Machine", lazy="joined")
 
-    def get_baseline_id(self):
+    def get_baseline_run(self):
         from ..entities.distribution import get_closest_parent
         from ..entities.summary import Summary
 
@@ -25,27 +25,31 @@ class Run(Base, EntityMixin):
         if not parent:
             return None
 
-        run_contexts = Summary.distinct(
-            Summary.context_id, filters=[Summary.run_id == self.id]
-        )
+        run_summaries = Summary.all(run_id=self.id)
+        run_items = [(s.context_id, s.case_id) for s in run_summaries]
 
-        # TODO: Should be using machine hash?
         parent_runs = Run.search(
-            filters=[Run.machine_id == self.machine_id, Commit.sha == parent.sha],
+            filters=[Commit.sha == parent.sha],
             joins=[Commit],
         )
 
-        # TODO: What if there are multiple matches? Pick by date?
-        # TODO: What is all the contexts just aren't yet in? Or some failed?
+        # TODO: What if all the contexts/cases just aren't yet in?
+        machine_hash = self.machine.hash
         for run in parent_runs:
-            parent_contexts = Summary.distinct(
-                Summary.context_id, filters=[Summary.run_id == run.id]
-            )
-            if set(run_contexts) == set(parent_contexts):
-                return run.id
+            if run.machine.hash != machine_hash:
+                continue
+
+            parent_summaries = Summary.all(run_id=run.id)
+            parent_items = [(s.context_id, s.case_id) for s in parent_summaries]
+            if set(run_items) == set(parent_items):
+                return run
 
         return None
 
+    def get_baseline_id(self):
+        run = self.get_baseline_run()
+        return run.id if run else None
+
 
 class _Serializer(EntitySerializer):
     def _dump(self, run):
