@@ -16,6 +16,7 @@ MUST_BE_INTS = [
     "cpu_l2_cache_bytes",
     "cpu_l3_cache_bytes",
     "memory_bytes",
+    "gpu_count",
 ]
 
 
@@ -45,6 +46,11 @@ MEMINFO_MAPPING = {
     "memory_bytes": "MemTotal",
 }
 
+NVIDIA_SMI_MAPPING = {
+    "gpu_count": None,
+    "gpu_product_names": None,
+}
+
 CPUINFO_MAPPING = {
     "cpu_model_name": "brand_raw",
     "cpu_l1d_cache_bytes": "l1_data_cache_size",
@@ -101,6 +107,8 @@ def machine_info(host_name):
         "cpu_l2_cache_bytes": None,
         "cpu_l3_cache_bytes": None,
         "cpu_frequency_max_hz": None,
+        "gpu_count": None,
+        "gpu_product_names": [],
     }
 
     _commands(info)
@@ -108,17 +116,19 @@ def machine_info(host_name):
     _lscpu(info)
     _cpuinfo(info)
     _psutil(info)
+    _nvidia_smi(info)
 
     for key in MUST_BE_INTS:
         try:
             int(info[key])
-        except ValueError:
+        except (ValueError, TypeError):
             info[key] = 0
 
     info["memory_bytes"] = _round_memory(int(info["memory_bytes"]))
 
     for key in info:
-        info[key] = str(info[key])
+        if not isinstance(info[key], list):
+            info[key] = str(info[key])
 
     return info
 
@@ -201,6 +211,25 @@ def _meminfo(info):
     _fill_from_meminfo(info, parts)
 
 
+def _nvidia_smi(info):
+    missing = _has_missing(info, NVIDIA_SMI_MAPPING)
+    if not missing:
+        return
+
+    try:
+        command = ["nvidia-smi", "--query-gpu=gpu_name", "--format=csv,noheader"]
+        result = subprocess.run(command, capture_output=True)
+        if result.returncode != 0:
+            return
+    except:
+        return
+
+    parts = result.stdout.decode("utf-8").strip().split("\n")
+    if parts:
+        info["gpu_count"] = len(parts)
+        info["gpu_product_names"] = parts
+
+
 def _fill_from_cpuinfo(info, cpu_info):
     for key, lookup in CPUINFO_MAPPING.items():
         if lookup not in cpu_info:
