@@ -90,7 +90,7 @@ class Benchmark(abc.ABC):
 
     @property
     def case_ids(self):
-        return [", ".join(case) for case in self.cases]
+        return [", ".join([str(c) for c in case]) for case in self.cases]
 
     def get_cases(self, case, options):
         run_all = options.get("all", False)
@@ -98,7 +98,14 @@ class Benchmark(abc.ABC):
 
     def _get_case(self, case, options):
         if case is None:
-            case = [options.get(c) for c in self.fields]
+            case = []
+            for i, c in enumerate(self.fields):
+                pick = self.cases[0][i]
+                if isinstance(pick, bool):
+                    case.append(options.get(c).lower() in ["True", "true"])
+                else:
+                    t = type(self.cases[0][i])
+                    case.append(t(options.get(c)))
         case_tuples = [tuple(c) for c in self.cases]
         if tuple(case) not in case_tuples:
             invalid_case = dict(zip(self.fields, case))
@@ -171,6 +178,10 @@ class Conbench(Connection):
             result.get("time_unit", "s"),
         )
 
+        batch_id = options.get("batch_id")
+        if batch_id:
+            self.batch_id = batch_id
+
         run_id = options.get("run_id")
         if run_id is None:
             run_id = self.batch_id
