@@ -72,8 +72,8 @@ def test_compare_no_change():
         "baseline_z_improvement": False,
         "contender_z_regression": False,
         "contender_z_improvement": False,
-        "baseline": "1.000K i/s",
-        "contender": "1.000K i/s",
+        "baseline": "1.000 K i/s",
+        "contender": "1.000 K i/s",
         "baseline_id": "some-benchmark-id-1",
         "contender_id": "some-benchmark-id-2",
         "baseline_batch_id": "some-batch-id-1",
@@ -157,7 +157,7 @@ def test_compare_regression():
         "baseline_z_improvement": False,
         "contender_z_regression": True,
         "contender_z_improvement": False,
-        "baseline": "1.000K i/s",
+        "baseline": "1.000 K i/s",
         "contender": "940 i/s",
         "baseline_id": "some-benchmark-id-1",
         "contender_id": "some-benchmark-id-2",
@@ -327,7 +327,7 @@ def test_compare_regression_but_under_threshold():
         "baseline_z_improvement": False,
         "contender_z_regression": False,
         "contender_z_improvement": False,
-        "baseline": "1.000K i/s",
+        "baseline": "1.000 K i/s",
         "contender": "950 i/s",
         "baseline_id": "some-benchmark-id-1",
         "contender_id": "some-benchmark-id-2",
@@ -415,7 +415,7 @@ def test_compare_regression_custom_threshold_and_threshold_z():
         "baseline_z_improvement": False,
         "contender_z_regression": True,
         "contender_z_improvement": False,
-        "baseline": "1.000K i/s",
+        "baseline": "1.000 K i/s",
         "contender": "950 i/s",
         "baseline_id": "some-benchmark-id-1",
         "contender_id": "some-benchmark-id-2",
@@ -500,8 +500,8 @@ def test_compare_improvement():
         "baseline_z_improvement": True,
         "contender_z_regression": False,
         "contender_z_improvement": True,
-        "baseline": "1.000K i/s",
-        "contender": "1.060K i/s",
+        "baseline": "1.000 K i/s",
+        "contender": "1.060 K i/s",
         "baseline_id": "some-benchmark-id-1",
         "contender_id": "some-benchmark-id-2",
         "baseline_batch_id": "some-batch-id-1",
@@ -673,8 +673,8 @@ def test_compare_improvement_but_under_threshold():
         "baseline_z_improvement": True,
         "contender_z_regression": False,
         "contender_z_improvement": True,
-        "baseline": "1.000K i/s",
-        "contender": "1.050K i/s",
+        "baseline": "1.000 K i/s",
+        "contender": "1.050 K i/s",
         "baseline_id": "some-benchmark-id-1",
         "contender_id": "some-benchmark-id-2",
         "baseline_batch_id": "some-batch-id-1",
@@ -758,8 +758,8 @@ def test_compare_improvement_custom_threshold_and_threshold_z():
         "baseline_z_improvement": False,
         "contender_z_regression": False,
         "contender_z_improvement": False,
-        "baseline": "1.000K i/s",
-        "contender": "1.050K i/s",
+        "baseline": "1.000 K i/s",
+        "contender": "1.050 K i/s",
         "baseline_id": "some-benchmark-id-1",
         "contender_id": "some-benchmark-id-2",
         "baseline_batch_id": "some-batch-id-1",
@@ -1003,7 +1003,7 @@ def test_compare_list_missing_contender():
             "improvement": False,
             "threshold_z": "5.000",
             "baseline_z_score": "0.000",
-            "contender_z_score": "0.000",
+            "contender_z_score": None,
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
             "contender_z_regression": False,
@@ -1059,7 +1059,7 @@ def test_compare_list_missing_contender():
             "improvement": False,
             "threshold_z": "5.000",
             "baseline_z_score": "0.000",
-            "contender_z_score": "0.000",
+            "contender_z_score": None,
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
             "contender_z_regression": False,
@@ -1165,7 +1165,7 @@ def test_compare_list_empty_contender():
             "improvement": False,
             "threshold_z": "5.000",
             "baseline_z_score": "0.000",
-            "contender_z_score": "0.000",
+            "contender_z_score": None,
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
             "contender_z_regression": False,
@@ -1221,7 +1221,7 @@ def test_compare_list_empty_contender():
             "improvement": False,
             "threshold_z": "5.000",
             "baseline_z_score": "0.000",
-            "contender_z_score": "0.000",
+            "contender_z_score": None,
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
             "contender_z_regression": False,
@@ -1325,7 +1325,7 @@ def test_compare_list_missing_baseline():
             "regression": False,
             "improvement": False,
             "threshold_z": "5.000",
-            "baseline_z_score": "0.000",
+            "baseline_z_score": None,
             "contender_z_score": "0.000",
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
@@ -1381,7 +1381,7 @@ def test_compare_list_missing_baseline():
             "regression": False,
             "improvement": False,
             "threshold_z": "5.000",
-            "baseline_z_score": "0.000",
+            "baseline_z_score": None,
             "contender_z_score": "0.000",
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
@@ -1487,7 +1487,7 @@ def test_compare_list_empty_baseline():
             "regression": False,
             "improvement": False,
             "threshold_z": "5.000",
-            "baseline_z_score": "0.000",
+            "baseline_z_score": None,
             "contender_z_score": "0.000",
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
@@ -1543,7 +1543,7 @@ def test_compare_list_empty_baseline():
             "regression": False,
             "improvement": False,
             "threshold_z": "5.000",
-            "baseline_z_score": "0.000",
+            "baseline_z_score": None,
             "contender_z_score": "0.000",
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
@@ -1616,8 +1616,8 @@ def test_compare_list_empty_pair():
             "regression": False,
             "improvement": False,
             "threshold_z": "5.000",
-            "baseline_z_score": "0.000",
-            "contender_z_score": "0.000",
+            "baseline_z_score": None,
+            "contender_z_score": None,
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
             "contender_z_regression": False,
@@ -1643,8 +1643,8 @@ def test_compare_list_empty_pair():
             "regression": False,
             "improvement": False,
             "threshold_z": "5.000",
-            "baseline_z_score": "0.000",
-            "contender_z_score": "0.000",
+            "baseline_z_score": None,
+            "contender_z_score": None,
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
             "contender_z_regression": False,
@@ -1672,8 +1672,8 @@ def test_compare_list_empty_pair():
             "regression": False,
             "improvement": False,
             "threshold_z": "5.000",
-            "baseline_z_score": "0.000",
-            "contender_z_score": "0.000",
+            "baseline_z_score": None,
+            "contender_z_score": None,
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
             "contender_z_regression": False,
@@ -1699,8 +1699,8 @@ def test_compare_list_empty_pair():
             "regression": False,
             "improvement": False,
             "threshold_z": "5.000",
-            "baseline_z_score": "0.000",
-            "contender_z_score": "0.000",
+            "baseline_z_score": None,
+            "contender_z_score": None,
             "baseline_z_regression": False,
             "baseline_z_improvement": False,
             "contender_z_regression": False,
